USTechFirms = {
    'head': ['symbol', 'companyName', 'industry', 'ceo', 'sector', 'price', 'mktCap'],
    'rows': [
        ['AAPL', 'Apple Inc.', 'Computer Hardware', 'Timothy D. Cook', 'Technology', 288.08, '1260488230000'],
        ['MSFT', 'Microsoft Corporation', 'Application Software', 'Satya Nadella', 'Technology', 168.07,
         '1223232060000'],
        ['FB', 'Facebook Inc.', 'Online Media', 'Mark Zuckerberg', 'Technology', 196.77, '560883040000'],
        ['NVDA', 'NVIDIA Corporation', 'Semiconductors', 'Jen-Hsun Huang', 'Technology', 262.05, '160374587000'],
        ['AMZN', 'Amazon.com Inc.', 'Online Media', 'Jeffrey P. Bezos', 'Technology', 1972.74, '982049690000'],
        ['GOOG', 'Alphabet Inc.', 'Online Media', 'Larry Page', 'Technology', 1388.45, '953677710000'],
        ['AMD', 'Advanced Micro Devices Inc.', 'Semiconductors', 'Lisa T. Su', 'Technology', 47.57, '55640728000'],
        ['QCOM', 'QUALCOMM Incorporated', 'Semiconductors', 'Steven M. Mollenkopf', 'Technology', 80.22, '88466620000'],
        ['CRM', 'Salesforce.com Inc', 'Application Software', 'Marc Benioff', 'Technology', 181.27, '160786498000'],
        ['INTC', 'Intel Corporation', 'Semiconductors', 'Brian M. Krzanich', 'Technology', 59.73, '245220917000'],
        ['TSM', 'Taiwan Semiconductor Manufacturing Company Ltd.', 'Semiconductors', 'Mark Liu / C.C Wei', 'Technology',
         53.86, '271774351000']
    ],
    'title': ''
}
