actresses = [
    'Kathy',
    'Anjelica',
    'Julia',
    'Meryl',
    'Joanne',
    'Jodie',
    'Geena',
    'Laura',
    'Bette',
    'Susan',
    'Emma',
    'Catherine',
    'Mary',
    'Michelle',
    'Susan',
    'Holly',
    'Angela',
    'Stockard',
    'Emma',
    'Debra',
    'Jessica',
    'Jodie',
    'Miranda',
    'Winona',
    'Susan',
    'Susan',
    'Elisabeth',
    'Sharon',
    'Meryl',
    'Emma',
    'Frances',
    'Brenda',
    'Diane',
    'Kristin',
    'Emily',
    'Helen',
    'Helena',
    'Julie',
    'Judi',
    'Kate',
    'Gwyneth',
    'Cate',
    'Fernanda',
    'Meryl',
    'Emily',
    'Hilary',
    'Annette',
    'Janet',
    'Julianne',
    'Meryl',
    'Julia',
    'Joan',
    'Juliette',
    'Ellen',
    'Laura',
    'Halle',
    'Judi',
    'Nicole',
    'Sissy',
    'Renée',
    'Nicole',
    'Salma',
    'Diane',
    'Julianne',
    'Renée',
    'Charlize',
    'Keisha',
    'Diane',
    'Samantha',
    'Naomi',
    'Hilary',
    'Annette',
    'Catalina',
    'Imelda',
    'Kate',
    'Reese',
    'Judi',
    'Felicity',
    'Keira',
    'Charlize',
    'Helen',
    'Penélope',
    'Judi',
    'Meryl',
    'Kate',
    'Marion',
    'Cate',
    'Julie',
    'Laura',
    'Ellen',
    'Kate',
    'Anne',
    'Angelina',
    'Melissa',
    'Meryl',
    'Sandra',
    'Helen',
    'Carey',
    'Gabourey',
    'Meryl',
]
