TopBoxOffice = {
    'head': ['name', 'boxoffice', 'budget', 'year', 'director', 'producer', 'writer', 'based_on'],
    'rows': [
        ['Avatar', '2,788', 244, '2009', 'James Cameron', ['James Cameron', 'Jon Landau'], 'James Cameron', ''],
        ['Titanic', '2,187', 200, '1997', 'James Cameron', ['James Cameron', 'Jon Landau'], 'James Cameron', ''],
        ['Star Wars: The Force Awakens', '2,068', 306, '2015', 'J. J. Abrams',
         ['Kathleen Kennedy', 'J. J. Abrams', 'Bryan Burk'], ['Lawrence Kasdan', 'J. J. Abrams', 'Michael Arndt'],
         'George Lucas'],
        ['Avengers: Infinity War', '2,048', 400, '2018', ['Anthony Russo', 'Joe Russo'], 'Kevin Feige',
         ['Christopher Markus', 'Stephen McFeely'], ['Stan Lee', 'Jack Kirby']],
        ['Jurassic World', '1,672', 150, '2015', 'Colin Trevorrow', ['Frank Marshall', 'Patrick Crowley'],
         ['Rick Jaffa', 'Amanda Silver', 'Derek Connolly', 'Colin Trevorrow'], 'Michael Crichton'],
        ['The Avengers', '1,519', 220, '2012', 'Joss Whedon', 'Kevin Feige', ['Joss Whedon', 'Zak Penn'],
         ['Stan Lee', 'Jack Kirby']],
        ['Furious 7', '1,516', 190, '2015', 'James Wan', ['Neal H. Moritz', 'Vin Diesel', 'Michael Fottrell'],
         'Chris Morgan', 'Gary Scott Thompson'],
        ['Avengers: Age of Ultron', '1,405', 495, '2015', 'Joss Whedon', 'Kevin Feige', 'Joss Whedon',
         ['Stan Lee', 'Jack Kirby']],
        ['Black Panther', '1,347', 210, '2018', 'Ryan Coogler', 'Kevin Feige', ['Ryan Coogler', 'Joe Robert Cole'],
         ['Stan Lee', 'Jack Kirby']],
        ['Harry Potter & Deathly Hallows II', '1,342', 250, '2011', 'David Yates',
         ['David Heyman', 'David Barron', 'J. K. Rowling'], 'Steve Kloves', 'J. K. Rowling'],
        ['Star Wars: The Last Jedi', '1,333', 317, '2017', 'Rian Johnson', ['Kathleen Kennedy', 'Ram Bergman'],
         'Rian Johnson', 'George Lucas'],
        ['Jurassic World: Fallen Kingdom', '1,309', 187, '2018', 'J. A. Bayona',
         ['Frank Marshall', 'Patrick Crowley', 'Belén Atienza'], ['Derek Connolly', 'Colin Trevorrow'],
         'Michael Crichton'],
        ['Frozen', '1,290', 150, '2013', ['Chris Buck', 'Jennifer Lee'], 'Peter Del Vecho',
         ['Chris Buck', 'Jennifer Lee', 'Shane Morris'], ''],
        ['Beauty and the Beast', '1,263', 255, '2017', 'Bill Condon', ['David Hoberman', 'Todd Lieberman'],
         ['Stephen Chbosky', 'Evan Spiliotopoulos'], 'Disney\'s'],
        ['Incredibles 2', '1,242', 200, '2018', 'Brad Bird', ['John Walker', 'Nicole Paradis Grindle'], 'Brad Bird',
         ''],
        ['The Fate of the Furious', '1,239', 250, '2017', 'F. Gary Gray',
         ['Neal H. Moritz', 'Vin Diesel', 'Michael Fottrell', 'Chris Morgan'], 'Chris Morgan', 'Gary Scott Thompson'],
        ['Iron Man 3', '1,215', 200, '2013', 'Shane Black', 'Kevin Feige', ['Drew Pearce', 'Shane Black'],
         ['Stan Lee', 'Don Heck', 'Larry Lieber', 'Jack Kirby']],
        ['Minions', '1,159', 74, '2015', ['Pierre Coffin', 'Kyle Balda'], ['Chris Meledandri', 'Janet Healy'],
         'Brian Lynch', 'Sergio Pablos'],
        ['Captain America: Civil War', '1,153', 250, '2016', ['Anthony Russo', 'Joe Russo'], 'Kevin Feige',
         ['Christopher Markus', 'Stephen McFeely'], ['Joe Simon', 'Jack Kirby']],
        ['Aquaman', '1,139', 200, '2018', 'James Wan', ['Peter Safran', 'Rob Cowan'],
         ['David Leslie Johnson-McGoldrick', 'Will Beall', 'Geoff Johns', 'James Wan'], 'Mort Weisinger']]
}
