# copyright: hbr.org
# link: https://hbr.org/visual-library/2018/03/how-marketing-moved-from-the-mass-market-era-to-the-era-of-relevance

# head = ['Era','Decade','Technology enabler','Perf indicator','Market approach','Management focus']
MarketingMovement = [
    ['Mass-market', 1960, 'Mass production', 'Volume', 'Mass appeal', 'Product & scale'],
    ['Segment', 1980, 'Market research', 'Purchase funnel', 'Segmentation', 'Channel & scale'],
    ['Customer', 1990, 'Enterprise IT', 'Customer lifetime value', 'Proposition innovation', 'Channel & relationship'],
    ['Loyalty', 2010, 'Advanced CRM', 'Customer retention', 'Tailored incentives', 'Experience & relationship'],
    ['Relevance', 2020, 'Digitization of everything', 'Customer attraction', 'Personalization',
     'Experience & personality'],
]
