car_plants = {
    'SantAgata': 'Lamborghini',
    'Angelholm': 'Koenigsegg',
    'Molsheim': 'Bugatti',
    'Gaydon': 'Aston Martin',
    'Maranello': 'Ferrari',
    'Stuttgart': 'Porsche',
    'Modena': 'Pagani',
    'Neckarsulm': 'Audi',
    'Crewe': 'Bentley',
    'Woking': 'McLaren',
    'Hethel': 'Lotus',
}
