military_robots = {
    'MechanicalHound': 'Fahrenheit 451',
    'AMEE': 'Red Planet',
    'SIMON': 'Lara Croft Tomb Raider',
    'ED209': 'RoboCop',
    'BattleRobotT1': 'Terminator 3 Rise of the Machines',
    'Johnny5': 'Short Circuit',
    'MARK': 'Hardware',
    'EDI': 'Stealth',
    'VTOLCraftT1': 'Terminator 3 Rise of the Machines',
    'CyberdyneT800': 'Terminator series',
    'EosB1': 'Star Wars Ep. I/II/III',
    'EosB2': 'Star Wars Ep. II/III',
    'HolowanMagnaGuards': 'Star Wars Ep. III',
    'Decepticons': 'Transformers',
    'HectorModel': 'Saturn 3',
    'STAR': 'The Black Hole',
    'CylonCenturion': 'Battlestar Galactica',
    'Protectron': 'Fallout',
    'SentryBot': 'Fallout',
    'LibertyPrime': 'Fallout',
    'CyberdyneT1000': 'Terminator 2 Judgment Day',
    'Terminatrix': 'Terminator 3 Rise of the Machines',
    'Synth': 'Fallout',
    'Sentinels': 'The Matrix series',
    'RobotB9': 'Lost in Space',
    'Droideka': 'Star Wars Ep. I,II,III',
    'R2D2': 'Star Wars series',
    'VINCENT': 'The Black Hole',
    'BOB': 'The Black Hole',
    'Maximilian': 'The Black Hole',
    'MisterGusty': 'Fallout series',
    'SuperSentinels': 'Halo 1/2/3',
    'Screamers': 'Screamers',
    'APU': 'The Matrix Revolutions',
    'IronManSuit': 'Iron Man',
    'AMP': 'Avatar',
    'MANTIS': 'M.A.N.T.I.S.',
    'PoweredInfantryArmorT51': 'Fallout series',
}
