film_actresses = {
    'Misery': 'Kathy Bates',
    'The Grifters': 'Anjelica Huston',
    'Pretty Woman': 'Julia Roberts',
    'Postcards from the Edge': 'Meryl Streep',
    'Mr. and Mrs. Bridge': 'Joanne Woodward',
    'The Silence of the Lambs': 'Jodie Foster',
    'Thelma & Louise': 'Geena Davis',
    'Rambling Rose': 'Laura Dern',
    'For the Boys': 'Bette Midler',
    'Thelma & Louise_': 'Susan Sarandon',
    'Howards End': 'Emma Thompson',
    'Indochine': 'Catherine Deneuve',
    'Passion Fish': 'Mary McDonnell',
    'Love Field': 'Michelle Pfeiffer',
    'Lorenzo\'s Oil': 'Susan Sarandon',
    'The Piano': 'Holly Hunter',
    'What\'s Love Got to Do with It': 'Angela Bassett',
    'Six Degrees of Separation': 'Stockard Channing',
    'The Remains of the Day': 'Emma Thompson',
    'Shadowlands': 'Debra Winger',
    'Blue Sky': 'Jessica Lange',
    'Nell': 'Jodie Foster',
    'Tom & Viv': 'Miranda Richardson',
    'Little Women': 'Winona Ryder',
    'The Client': 'Susan Sarandon',
    'Dead Man Walking': 'Susan Sarandon',
    'Leaving Las Vegas': 'Elisabeth Shue',
    'Casino': 'Sharon Stone',
    'The Bridges of Madison County': 'Meryl Streep',
    'Sense and Sensibility': 'Emma Thompson',
    'Fargo': 'Frances McDormand',
    'Secrets & Lies': 'Brenda Blethyn',
    'Marvin\'s Room': 'Diane Keaton',
    'The English Patient': 'Kristin Scott Thomas',
    'Breaking the Waves': 'Emily Watson',
    'As Good as It Gets': 'Helen Hunt',
    'The Wings of the Dove': 'Helena Bonham Carter',
    'Afterglow': 'Julie Christie',
    'Mrs. Brown': 'Judi Dench',
    'Titanic': 'Kate Winslet',
    'Shakespeare in Love': 'Gwyneth Paltrow',
    'Elizabeth': 'Cate Blanchett',
    'Central Station': 'Fernanda Montenegro',
    'One True Thing': 'Meryl Streep',
    'Hilary and Jackie': 'Emily Watson',
    'Boys Don\'t Cry': 'Hilary Swank',
    'American Beauty': 'Annette Bening',
    'Tumbleweeds': 'Janet McTeer',
    'The End of the Affair': 'Julianne Moore',
    'Music of the Heart': 'Meryl Streep',
    'Erin Brockovich': 'Julia Roberts',
    'The Contender': 'Joan Allen',
    'Chocolat': 'Juliette Binoche',
    'Requiem for a Dream': 'Ellen Burstyn',
    'You Can Count on Me': 'Laura Linney',
    'Monster\'s Ball': 'Halle Berry',
    'Iris': 'Judi Dench',
    'Moulin Rouge!': 'Nicole Kidman',
    'In the Bedroom': 'Sissy Spacek',
    'Bridget Jones\'s Diary': 'Renée Zellweger',
    'The Hours': 'Nicole Kidman',
    'Frida': 'Salma Hayek',
    'Unfaithful': 'Diane Lane',
    'Far from Heaven': 'Julianne Moore',
    'Chicago': 'Renée Zellweger',
    'Monster': 'Charlize Theron',
    'Whale Rider': 'Keisha Castle-Hughes',
    'Something\'s Gotta Give': 'Diane Keaton',
    'In America': 'Samantha Morton',
    '21 Grams': 'Naomi Watts',
    'Million Dollar Baby': 'Hilary Swank',
    'Being Julia': 'Annette Bening',
    'Maria Full of Grace': 'Catalina Sandino Moreno',
    'Vera Drake': 'Imelda Staunton',
    'Eternal Sunshine of the Spotless Mind': 'Kate Winslet',
    'Walk the Line': 'Reese Witherspoon',
    'Mrs Henderson Presents': 'Judi Dench',
    'Transamerica': 'Felicity Huffman',
    'Pride & Prejudice': 'Keira Knightley',
    'North Country': 'Charlize Theron',
    'The Queen': 'Helen Mirren',
    'Volver': 'Penélope Cruz',
    'Notes on a Scandal': 'Judi Dench',
    'The Devil Wears Prada': 'Meryl Streep',
    'Little Children': 'Kate Winslet',
    'La Vie en Rose': 'Marion Cotillard',
    'Elizabeth: The Golden Age': 'Cate Blanchett',
    'Away from Her': 'Julie Christie',
    'The Savages': 'Laura Linney',
    'Juno': 'Ellen Page',
    'The Reader': 'Kate Winslet',
    'Rachel Getting Married': 'Anne Hathaway',
    'Changeling': 'Angelina Jolie',
    'Frozen River': 'Melissa Leo',
    'Doubt': 'Meryl Streep',
    'The Blind Side': 'Sandra Bullock',
    'The Last Station': 'Helen Mirren',
    'An Education': 'Carey Mulligan',
    'Precious': 'Gabourey Sidibe',
    'Julie & Julia': 'Meryl Streep',
}
