from foba.tabulars.tables.AeroEngineSpecs import AeroEngineSpecs
from foba.tabulars.tables.AoEIIUnits import AoEIIUnits
from foba.tabulars.tables.BigMacAdjustedIndexes import BigMacAdjustedIndexes
from foba.tabulars.tables.BistroDutyRoster import BistroDutyRoster
from foba.tabulars.tables.ChinaConceptFirms import ChinaConceptFirms
from foba.tabulars.tables.FrontierEconomies import FrontierEconomies
from foba.tabulars.tables.TopBoxOffice import TopBoxOffice
from foba.tabulars.tables.USTechFirms import USTechFirms

table_collection = {
    'AeroEngineSpecs': AeroEngineSpecs,
    'AoEIIUnits': AoEIIUnits,
    'BigMacAdjustedIndexes': BigMacAdjustedIndexes,
    'BistroDutyRoster': BistroDutyRoster,
    'ChinaConceptFirms': ChinaConceptFirms,
    'FrontierEconomies': FrontierEconomies,
    'TopBoxOffice': TopBoxOffice,
    'USTechFirms': USTechFirms,
}
