softwoods = {
    'DouglasFir': 'joinery, doors and heavy construction',
    'EasternWhitePine': 'furniture',
    'EuropeanSpruce': 'used throughout construction, panelling and cladding',
    'Larch': 'used for cladding and boats',
    'LodgepolePine': 'roofing, flooring and in making chipboard and particle board[4]',
    'ParanaPine': 'stair treads and joinery',
    'RedCeda': 'furniture, decking, cladding, and roof shingles',
    'ScotsPine': 'construction industry, mostly for interior work',
    'SitkaSpruce': 'musical instrument, airplane',
    'SouthernYellowPine': 'joinery, flooring and decking',
    'WesternHemlock': 'doors, joinery and furniture',
    'Yew': 'interior and exterior furniture e.g. chairs, gate posts and wood turning',
}
