movie_quotes = dict([
  ('Love Story', "Love means never having to say you're sorry.",),
  ('Braveheart', "They may take our lives, but they'll never take our freedom!",),
  ('In the Heat of the Night', "They call me Mister Tibbs!",),
  ('When Harry Met Sally', "When you realize you want to spend the rest of your life with somebody, you want the rest of your life to start as soon as possible.",),
  ('Taken', "If you let my daughter go now, that'll be the end of it. I will not look for you, I will not pursue you. But if you don't, I will look for you, I will find you, and I will kill you.",),
  ('Jerry Maguire', "You complete me.",),
  ('Gladiator', "My name is Maximus Decimus Meridius, commander of the Armies of the North, General of the Felix Legions and loyal servant to the true emperor, Marcus Aurelius. Father to a murdered son, husband to a murdered wife. And I will have my vengeance, in this life or the next.",),
  ('There Will Be Blood', "I drink your milkshake!",),
  ('Planet of the Apes', "Get your stinking paws off me, you damned dirty ape!",),
  ('As Good as It Gets', "You make me want to be a better man.",),
  ('Clueless', "As if!",),
  ('Star Wars Episode VII: The Force Awakens', "Chewie, we're home.",),
  ('Chinatown', "Forget it, Jake. It's Chinatown.",),
  ('This Is Spinal Tap', "These go to eleven.",),
  ('Midnight Cowboy', "I'm walking here! I'm walking here!",),
  ('King Kong', "It was Beauty killed the Beast.",),
  ('The Treasure of the Sierra Madre', "Badges? We ain't got no badges! We don't need no badges! I don't have to show you any stinking badges!",),
  ('The Devil Wears Prada', "I'm just one stomach flu away from my goal weight.",),
  ('Pulp Fiction', "They call it a Royale with cheese.",),
  ('Poltergeist', "They're here!",),
  ('Snow White and the Seven Dwarves', "Magic Mirror on the wall, who is the fairest one of all?",),
  ('The Godfather: Part III', "Just when I thought I was out, they pull me back in.",),
  ('Some Like It Hot', "Nobody's perfect.",),
  ('Rocky', "Yo, Adrian!",),
  ('The Karate Kid', "Wax on, wax off.",),
  ('The Jazz Singer', "You ain't heard nothin' yet!",),
  ('Dr. Strangelove', "Gentlemen, you can't fight in here! This is the war room!",),
  ('12 Years a Slave', "I don't want to survive. I want to live.",),
  ('The Adventures of Sherlock Holmes', "Elementary, my dear Watson.",),
  ('Babe', "That'll do, pig. That'll do.",),
  ('Brokeback Mountain', "I wish I knew how to quit you.",),
  ('Good Morning', "Good morning, Vietnam!",),
  ('The Lord of the Rings: The Two Towers', "My precious.",),
  ('Argo', "Argo f— yourself.",),
  ('Frankenstein', "It's alive! It's alive!",),
  ('A Streetcar Named Desire', "I have always depended on the kindness of strangers.",),
  ('Sudden Impact', "Go ahead, make my day.",),
  ('Goodfellas', "I mean, funny like I'm a clown? I amuse you?",),
  ('Star Wars', "Help me, Obi-Wan Kenobi. You're my only hope.",),
  ('To Have and Have Not', "You know how to whistle, don't you, Steve? You just put your lips together and blow.",),
  ('The Help', "You is kind. You is smart. You is important.",),
  ('Gone With the Wind', "After all, tomorrow is another day!",),
  ('A Streetcar Named Desire', "Stella! Hey, Stella!",),
  ('The Wizard of Oz', "Pay no attention to that man behind the curtain!",),
  ('Notting Hill', "I'm also just a girl, standing in front of a boy, asking him to love her.",),
  ('The Big Lebowski', "The Dude abides.",),
  ('Terminator 2: Judgment Day', "Hasta la vista, baby.",),
  ('The Wizard of Oz', "I'll get you, my pretty, and your little dog, too!",),
  ('Casablanca', "Play it, Sam. Play 'As Time Goes By.'",),
  ('The Silence of the Lambs', "I'm having an old friend for dinner.",),
  ('Who Framed Roger Rabbit', "I'm not bad. I'm just drawn that way.",),
  ('Field of Dreams', "If you build it, he will come.",),
  ('Finding Nemo', "Just keep swimming.",),
  ('Forrest Gump', "Mama says, 'Stupid is as stupid does.'",),
  ('Titanic', "I'm the king of the world!",),
  ('Goldfinger', "Shaken, not stirred.",),
  ('Cool Hand Luke', "What we've got here is a failure to communicate.",),
  ('Sunset Boulevard', "I am big! It's the pictures that got small.",),
  ('It\'s a Wonderful Life', "Every time a bell rings, an angel gets his wings.",),
  ('The Godfather', "Keep your friends close, but your enemies closer.",),
  ('The Usual Suspects', "The greatest trick the devil ever pulled was convincing the world he didn't exist.",),
  ('Network', "I'm as mad as hell, and I'm not going to take this anymore!",),
  ('On the Waterfront', "You don't understand! I could've had class. I could've been a contender. I could've been somebody, instead of a bum, which is what I am.",),
  ('Back to the Future', "Roads? Where we're going we don't need roads.",),
  ('All About Eve', "Fasten your seatbelts. It's going to be a bumpy night.",),
  ('Apocalypse Now', "I love the smell of napalm in the morning.",),
  ('Dirty Harry', "You've got to ask yourself one question: 'Do I feel lucky?' Well, do ya punk?",),
  ('Scarface', "Say hello to my little friend!",),
  ('Jerry Maguire', "Show me the money!",),
  ('The Godfather', "Leave the gun. Take the cannoli.",),
  ('Dead Poets Society', "Carpe diem. Seize the day, boys.",),
  ('The Graduate', "Mrs. Robinson, you're trying to seduce me, aren't you?",),
  ('Airplane', "I am serious. And don't call me Shirley.",),
  ('The Shining', "Here's Johnny!",),
  ('A League of Their Own', "There's no crying in baseball!",),
  ('Jerry Maguire', "You had me at hello.",),
  ('Apollo 13', "Houston, we have a problem.",),
  ('Toy Story', "To infinity and beyond!",),
  ('Die Hard', "Yippie-ki-yay, motherf—er!",),
  ('E.T. the Extra-Terrestrial', "E.T. phone home.",),
  ('A Few Good Men', "You can't handle the truth!",),
  ('The Terminator', "I'll be back.",),
  ('The Sixth Sense', "I see dead people.",),
  ('Dr. No', "Bond. James Bond.",),
  ('Casablanca', "We'll always have Paris.",),
  ('Casablanca', "This is the beginning of a beautiful friendship.",),
  ('When Harry Met Sally', "I'll have what she's having.",),
  ('The Dark Knight', "Why so serious?",),
  ('The Princess Bride', "Hello. My name is Inigo Montoya. You killed my father. Prepare to die.",),
  ('Star Wars Episode V: The Empire Strikes Back', "I am your father.",),
  ('Fight Club', "The first rule of Fight Club is: You do not talk about Fight Club.",),
  ('The Wizard of Oz', "There's no place like home.",),
  ('Taxi Driver', "You talkin' to me?",),
  ('Casablanca', "Of all the gin joints in all the towns in all the world, she walks into mine.",),
  ('The Godfather', "I'm going to make him an offer he can't refuse.",),
  ('The Wizard of Oz', "Toto, I've a feeling we're not in Kansas anymore.",),
  ('Star Wars', "May the Force be with you.",),
  ('Jaws', "You're gonna need a bigger boat.",),
  ('Casablanca', "Here's looking at you, kid.",),
  ('Gone With the Wind', "Frankly, my dear, I don't give a damn.",),
])


