AoEIIUnitsAttackByStages = {
    'side': ['Imperial', 'Castle', 'Feudal', 'Dark'],
    'head': ['Barracks', 'Archery Range', 'Stable', 'Siege Workshop'],
    'rows': [
        [9.8, 10, 10, 31.3],
        [6.7, 4.7, 7.3, 18],
        [4.5, 3, 5, None],
        [4, None, None, None],
    ],
}
