AoEIIUnitsHpByStages = {
    'side': ['Imperial', 'Castle', 'Feudal', 'Dark'],
    'head': ['Barracks', 'Archery Range', 'Stable', 'Siege Workshop'],
    'rows': [
        [62.5, 45, 118.8, 121.7],
        [53.3, 40, 86.7, 88.3],
        [45, 17, 45, None],
        [40, None, None, None],
    ],
}
