film_directors = {
    'Dances with Wolves': 'Kevin Costner',
    'The Godfather Part III': 'Francis Ford Coppola',
    'The Grifters': 'Stephen Frears',
    'Reversal of Fortune': 'Barbet Schroeder',
    'Goodfellas': 'Martin Scorsese',
    'The Silence of the Lambs': 'Jonathan Demme',
    'Bugsy': 'Barry Levinson',
    'Thelma & Louise': 'Ridley Scott',
    'Boyz n the Hood': 'John Singleton',
    'JFK': 'Oliver Stone',
    'Unforgiven': 'Clint Eastwood',
    'The Player': 'Robert Altman',
    'Scent of a Woman': 'Martin Brest',
    'Howards End': 'James Ivory',
    'The Crying Game': 'Neil Jordan',
    'Schindler\'s List': 'Steven Spielberg',
    'Short Cuts': 'Robert Altman',
    'The Piano': 'Jane Campion',
    'The Remains of the Day': 'James Ivory',
    'In the Name of the Father': 'Jim Sheridan',
    'Forrest Gump': 'Robert Zemeckis',
    'Bullets Over Broadway': 'Woody Allen',
    'Three Colors: Red': 'Krzysztof Kieślowski',
    'Quiz Show': 'Robert Redford',
    'Pulp Fiction': 'Quentin Tarantino',
    'Braveheart': 'Mel Gibson',
    'Leaving Las Vegas': 'Mike Figgis',
    'Babe': 'Chris Noonan',
    'Il Postino': 'Michael Radford',
    'Dead Man Walking': 'Tim Robbins',
    'The English Patient': 'Anthony Minghella',
    'Fargo': 'Joel Coen',
    'The People vs. Larry Flynt': 'Miloš Forman',
    'Shine': 'Scott Hicks',
    'Secrets & Lies': 'Mike Leigh',
    'Titanic': 'James Cameron',
    'The Full Monty': 'Peter Cattaneo',
    'The Sweet Hereafter': 'Atom Egoyan',
    'L.A. Confidential': 'Curtis Hanson',
    'Good Will Hunting': 'Gus Van Sant',
    'Saving Private Ryan': 'Steven Spielberg',
    'Life Is Beautiful': 'Roberto Benigni',
    'Shakespeare in Love': 'John Madden',
    'The Thin Red Line': 'Terrence Malick',
    'The Truman Show': 'Peter Weir',
    'American Beauty': 'Sam Mendes',
    'The Cider House Rules': 'Lasse Hallström',
    'Being John Malkovich': 'Spike Jonze',
    'The Insider': 'Michael Mann',
    'The Sixth Sense': 'M. Night Shyamalan',
    'Traffic': 'Steven Soderbergh',
    'Billy Elliot': 'Stephen Daldry',
    'Crouching Tiger, Hidden Dragon': 'Ang Lee',
    'Gladiator': 'Ridley Scott',
    'Erin Brockovich': 'Steven Soderbergh',
    'A Beautiful Mind': 'Ron Howard',
    'Gosford Park': 'Robert Altman',
    'The Lord of the Rings: The Fellowship of the Ring': 'Peter Jackson',
    'Mulholland Drive': 'David Lynch',
    'The Pianist': 'Roman Polanski',
    'Black Hawk Down': 'Ridley Scott',
    'Talk to Her': 'Pedro Almodóvar',
    'The Hours': 'Stephen Daldry',
    'Chicago': 'Rob Marshall',
    'The Lord of the Rings: The Return of the King': 'Peter Jackson',
    'Gangs of New York': 'Martin Scorsese',
    'Lost in Translation': 'Sofia Coppola',
    'Mystic River': 'Clint Eastwood',
    'City of God': 'Fernando Meirelles',
    'Master and Commander: The Far Side of the World': 'Peter Weir',
    'Million Dollar Baby': 'Clint Eastwood',
    'Ray': 'Taylor Hackford',
    'Vera Drake': 'Mike Leigh',
    'Sideways': 'Alexander Payne',
    'The Aviator': 'Martin Scorsese',
    'Brokeback Mountain': 'Ang Lee',
    'Good Night, and Good Luck.': 'George Clooney',
    'Crash': 'Paul Haggis',
    'Capote': 'Bennett Miller',
    'Munich': 'Steven Spielberg',
    'The Departed': 'Martin Scorsese',
    'Letters from Iwo Jima': 'Clint Eastwood',
    'The Queen': 'Stephen Frears',
    'Babel': 'Alejandro González Iñárritu',
    'United 93': 'Paul Greengrass',
    'No Country for Old Men': 'Joel & Ethan Coen',
    'There Will Be Blood': 'Paul Thomas Anderson',
    'Michael Clayton': 'Tony Gilroy',
    'Juno': 'Jason Reitman',
    'The Diving Bell and the Butterfly': 'Julian Schnabel',
    'Slumdog Millionaire': 'Danny Boyle',
    'The Reader': 'Stephen Daldry',
    'The Curious Case of Benjamin Button': 'David Fincher',
    'Frost/Nixon': 'Ron Howard',
    'Milk': 'Gus Van Sant',
    'Avatar': 'James Cameron',
    'The Hurt Locker': 'Kathryn Bigelow',
    'Precious: Based on the Novel "Push" by Sapphire': 'Lee Daniels',
    'Up in the Air': 'Jason Reitman',
    'Inglourious Basterds': 'Quentin Tarantino',
}
