film_actors = {
    'Reversal of Fortune': 'Jeremy Irons',
    'Dances with Wolves': 'Kevin Costner',
    'Awakenings': 'Robert De Niro',
    'Cyrano de Bergerac': 'Gérard Depardieu',
    'The Field': 'Richard Harris',
    'The Silence of the Lambs': 'Anthony Hopkins',
    'Bugsy': 'Warren Beatty',
    'Cape Fear': 'Robert De Niro',
    'The Prince of Tides': 'Nick Nolte',
    'The Fisher King': 'Robin Williams',
    'Scent of a Woman': 'Al Pacino',
    'Chaplin': 'Robert Downey, Jr.',
    'Unforgiven': 'Clint Eastwood',
    'The Crying Game': 'Stephen Rea',
    'Malcolm X': 'Denzel Washington',
    'Philadelphia': 'Tom Hanks',
    'In the Name of the Father': 'Daniel Day-Lewis',
    'What\'s Love Got to Do with It': 'Laurence Fishburne',
    'The Remains of the Day': 'Anthony Hopkins',
    'Schindler\'s List': 'Liam Neeson',
    'Forrest Gump': 'Tom Hanks',
    'The Shawshank Redemption': 'Morgan Freeman',
    'The Madness of King George': 'Nigel Hawthorne',
    'Nobody\'s Fool': 'Paul Newman',
    'Pulp Fiction': 'John Travolta',
    'Leaving Las Vegas': 'Nicolas Cage',
    'Mr. Holland\'s Opus': 'Richard Dreyfuss',
    'Nixon': 'Anthony Hopkins',
    'Dead Man Walking': 'Sean Penn',
    'Il Postino': 'Massimo Troisi',
    'Shine': 'Geoffrey Rush',
    'Jerry Maguire': 'Tom Cruise',
    'The English Patient': 'Ralph Fiennes',
    'The People vs. Larry Flynt': 'Woody Harrelson',
    'Sling Blade': 'Billy Bob Thornton',
    'As Good as It Gets': 'Jack Nicholson',
    'Good Will Hunting': 'Matt Damon',
    'The Apostle': 'Robert Duvall',
    'Ulee\'s Gold': 'Peter Fonda',
    'Wag the Dog': 'Dustin Hoffman',
    'Life Is Beautiful': 'Roberto Benigni',
    'Saving Private Ryan': 'Tom Hanks',
    'Gods and Monsters': 'Ian McKellen',
    'Affliction': 'Nick Nolte',
    'American History X': 'Edward Norton',
    'American Beauty': 'Kevin Spacey',
    'The Insider': 'Russell Crowe',
    'The Straight Story': 'Richard Farnsworth',
    'Sweet and Lowdown': 'Sean Penn',
    'The Hurricane': 'Denzel Washington',
    'Gladiator': 'Russell Crowe',
    'Before Night Falls': 'Javier Bardem',
    'Cast Away': 'Tom Hanks',
    'Pollock': 'Ed Harris',
    'Quills': 'Geoffrey Rush',
    'Training Day': 'Denzel Washington',
    'A Beautiful Mind': 'Russell Crowe',
    'I Am Sam': 'Sean Penn',
    'Ali': 'Will Smith',
    'In the Bedroom': 'Tom Wilkinson',
    'The Pianist': 'Adrien Brody',
    'Adaptation.': 'Nicolas Cage',
    'The Quiet American': 'Michael Caine',
    'Gangs of New York': 'Daniel Day-Lewis',
    'About Schmidt': 'Jack Nicholson',
    'Mystic River': 'Sean Penn',
    'Pirates of the Caribbean: The Curse of the Black Pearl': 'Johnny Depp',
    'House of Sand and Fog': 'Ben Kingsley',
    'Cold Mountain': 'Jude Law',
    'Lost in Translation': 'Bill Murray',
    'Ray': 'Jamie Foxx',
    'Hotel Rwanda': 'Don Cheadle',
    'Finding Neverland': 'Johnny Depp',
    'The Aviator': 'Leonardo DiCaprio',
    'Million Dollar Baby': 'Clint Eastwood',
    'Capote': 'Philip Seymour Hoffman',
    'Hustle & Flow': 'Terrence Howard',
    'Brokeback Mountain': 'Heath Ledger',
    'Walk the Line': 'Joaquin Phoenix',
    'Good Night, and Good Luck': 'David Strathairn',
    'The Last King of Scotland': 'Forest Whitaker',
    'Blood Diamond': 'Leonardo DiCaprio',
    'Half Nelson': 'Ryan Gosling',
    'Venus': 'Peter O\'Toole',
    'The Pursuit of Happyness': 'Will Smith',
    'There Will Be Blood': 'Daniel Day-Lewis',
    'Michael Clayton': 'George Clooney',
    'Sweeney Todd: The Demon Barber of Fleet Street': 'Johnny Depp',
    'In the Valley of Elah': 'Tommy Lee Jones',
    'Eastern Promises': 'Viggo Mortensen',
    'Milk': 'Sean Penn',
    'The Visitor': 'Richard Jenkins',
    'Frost/Nixon': 'Frank Langella',
    'The Curious Case of Benjamin Button': 'Brad Pitt',
    'The Wrestler': 'Mickey Rourke',
    'Crazy Heart': 'Jeff Bridges',
    'Up in the Air': 'George Clooney',
    'A Single Man': 'Colin Firth',
    'Invictus': 'Morgan Freeman',
    'The Hurt Locker': 'Jeremy Renner',
}
