# copyright: hbr.org
# link: https://hbr.org/2019/12/build-a-culture-to-match-your-brand

CompanyBrandTypes = [
    ['Disruptive', 'Category leader', 'Rebellious, confident, daring', ['Virgin', 'Airbnb', 'Dr Pepper'], ],
    ['Conscious', 'Higher purpose', 'Inspiring, thoughtful, transparent',
     ['Seventh', 'Generation', 'SoulCycle', 'Patagonia'], ],
    ['Service', 'Customer need', 'Humble, predictable, friendly', ['Nordstrom', 'USAA', 'Ritz Carlton'], ],
    ['Innovative', 'Possibility', 'Risk-taking, imaginative, progressive', ['Apple', 'Nike', 'Amazon'], ],
    ['Value', 'Higher-priced brand', 'Down-to-earth, practical, straightforward', ['Walmart', 'IKEA', 'Subway'], ],
    ['Performance', 'Performance standard', 'Precise, competent, reliable', ['BMW', 'FedEx', 'American Express'], ],
    ['Luxury', 'Populist brand', 'Discriminating, refined, glamorous', ['Tiffany', 'Mercedes-Benz', 'Hermes'], ],
    ['Style', 'Functional brand', 'Creative, stylish, contemporary', ['Target', 'JetBlue', 'Mini Cooper'], ],
    ['Experience', 'Customer emotion', 'Exciting, energetic, imaginative', ['Disney', 'American Girl', 'Wegmans'], ],
]
