ChinaConceptFirms = {
    'head': ['symbol', 'companyName', 'industry', 'ceo', 'sector', 'price', 'mktCap'],
    'rows': [
        ['JD', 'JD.com Inc.', 'Online Media', 'Qiangdong Richard Liu', 'Technology', 38.84, '56712614000'],
        ['BABA', 'Alibaba Group Holding Limited', 'Retail - Apparel & Specialty', 'Yong Daniel Zhang',
         'Consumer Cyclical', 205.61, '563679790000'],
        ['NTES', 'NetEase Inc.', 'Online Media', 'William Lei Ding', 'Technology', 337.91, '43239301000'],
        ['BIDU', 'Baidu Inc.', 'Online Media', 'Yanhong Robin Li', 'Technology', 124.43, '43114873000'],
        ['EDU', 'New Oriental Education', 'Education', 'Chenggang Zhou', 'Consumer Defensive', 134.47, '21303947300'],
        ['PDD', 'Pinduoduo Inc.', 'Internet Retail', None, 'Consumer Cyclical', 32.8, '38125408000'],
        ['YUMC', 'Yum China Holdings Inc.', 'Restaurants', 'Muktesh Pant', 'Consumer Cyclical', 43.81, '16468573200'],
        ['TME', 'Tencent Music Entertainment', 'Internet Content & Information', None, 'Communication Services', 12.32,
         '20760062000'],
        ['IQ', 'iQIYI, Inc.', 'Internet Content & Information', None, 'Communication Services', 23.98, '17434419200'],
        ['BILI', 'Bilibili Inc.', 'Electronic Gaming & Multimedia', None, 'Communication Services', 26.72,
         '8714006500'],
        ['LK', 'Luckin Coffee Inc.', 'Restaurants', None, 'Consumer Cyclical', 38.33, '8964160500']],
    'title': '',
}
