from .dict_numbers import \
    arm_sales, \
    brent_prices, \
    mega_cities, \
    mortality_rates, \
    power_cars, \
    recessions, \
    dict_collection as number_dict_collection

from .dict_strings import \
    car_plants, \
    film_actors, \
    film_actresses, \
    film_directors, \
    military_robots, \
    movie_quotes, \
    pastas, \
    softwoods, \
    dict_collection as string_dict_collection
