# copyright: hbr.org
# link: https://hbr.org/2016/12/mapping-frontier-economies

FrontierEconomies = {
    'head': ['no', 'country', 'cagr', 'frontier', 'corruption', 'arbitary', 'income', 'sig drop in gdppc'],
    'rows': [
        [1, 'Bhutan', '8.47%', False, None, None, None, None],
        [2, 'Libya', '8.04%', True, True, True, None, True],
        [3, 'Myanmar', '7.88%', True, True, True, True, None],
        [4, 'Cote D\'ivore', '7.71%', True, True, None, True, None],
        [5, 'India', '7.58%', False, None, None, None, None],
        [6, 'Lao P.D.R.', '7.37%', True, True, None, None, None],
        [7, 'Mozambique', '7.16%', True, True, None, True, None],
        [8, 'Cambodia', '6.94%', True, True, None, True, None],
        [9, 'Senegal', '6.92%', True, None, None, True, None],
        [10, 'Rwanda', '6.86%', True, None, None, True, None],
        [11, 'Bangladesh', '6.84%', True, True, None, True, None],
        [12, 'Ethiopia', '6.80%', True, True, None, True, None],
        [13, 'Niger', '6.75%', True, True, None, True, None],
        [14, 'Tanzania', '6.72%', True, True, None, True, None],
        [15, 'Djibouti', '6.70%', True, True, None, None, True],
        [16, 'Kenya', '6.31%', True, True, None, True, None],
        [17, 'Panama', '6.30%', False, None, None, None, None],
        [18, 'Philippines', '6.28%', False, None, None, None, None],
        [19, 'Vietnam', '6.22%', True, True, None, None, None],
        [20, 'China', '6.14%', False, None, None, None, None],
        [21, 'Brunei', '6.11%', False, None, None, None, None],
        [22, 'Ghana', '5.94%', True, True, None, True, None],
        [23, 'Uganda', '5.85%', True, True, None, True, None],
        [24, 'Burkina Faso', '5.74%', True, True, None, True, None],
        [25, 'UzbekistanZ', '5.71%', True, True, True, None, None],
    ]
}
