# copyright: hbr.org
# link: https://hbr.org/visual-library/2020/01/cultural-differences-in-assessing-trust-in-negotiating-partners

# x +: Interdependence
# x -: Independence
# y +: Flexibility
# y -: Stability
# head = ['interdependence', 'flexibility', 'culture']

IntegratedCultureFramework = [
    ['+1', '+2', 'Purpose'],
    ['+2', '+1', 'Caring'],
    ['+2', '-1', 'Order'],
    ['+1', '-2', 'Safety'],
    ['-1', '-2', 'Authority'],
    ['-2', '-1', 'Results'],
    ['-2', '+1', 'Enjoyment'],
    ['-1', '+2', 'Learning'],
]
