from .dicts import number_dict_collection, string_dict_collection
from .matrices import number_matrix_collection, string_matrix_collection
from .objects import object_collection
from .tabulars import crostab_collection, table_collection
from .vectors import number_vector_collection, string_vector_collection
