# https://www.sipri.org/databases/armsindustry
# in millions USD
arm_sales = {
    'LockheedMartin': 47260,
    'Boeing': 29150,
    'NorthropGrumman': 26190,
    'Raytheon': 23440,
    'GeneralDynamics': 22000,
    'BAESystemsUK': 21210,
    'AirbusGroup': 11650,
    'BAESystemsUS': 10800,
    'Leonardo': 9820,
    'AlmazAntey': 9640,
    'Thales': 9470,
    'UnitedTechnologies': 9310,
    'L3Technologies': 8250,
    'HuntingtonIngallsInd': 7200,
    'HoneywellIntr': 5430,
    'UnitedAircraft': 5420,
    'Leidos': 5000,
    'Harris': 4970,
    'UnitedShipbuilding': 4700,
    'BoozAllenHamilton': 4680,
    'RollsRoyce': 4680,
    'NavalGroup': 4220,
    'Rheinmetall': 3800,
    'MBDA': 3780,
    'GeneralElectric': 3650,
    'MitsubishiHeavyInd': 3620,
    'TacticalMissiles': 3600,
    'Textron': 3500,
    'ElbitSystems': 3500,
    'CACIIntr': 3490,
    'Saab': 3240,
    'Safran': 3240,
    'Sandia': 3200,
    'BabcockIntr': 3180,
    'UnitedEngine': 2950,
    'DassaultAviation': 2930,
    'ScienceApplicationsIntr': 2800,
    'AECOM': 2770,
    'GeneralAtomics': 2750,
    'HindustanAeronautics': 2740,
    'AirbusHelicoptersInc': 2730,
    'IsraelAerospaceInd': 2650,
    'HighPrecisionSystems': 2630,
    'RockwellCollins': 2630,
    'KBR': 2600,
    'Perspecta': 2590,
    'Rafael': 2540,
    'RussianElectronics': 2330,
    'HanwhaAerospace': 2320,
    'CEA': 2300,
    'KawasakiHeavyInd': 2260,
    'BellHelicopterTextron': 2030,
    'Bechtel': 2000,
    'Fincantieri': 1900,
    'Oshkosh': 1850,
    'RussianHelicopters': 1810,
    'KRET': 1770,
    'ASELSAN': 1740,
    'KraussMaffeiWegmann': 1680,
    'IndianOrdnanceFactories': 1650,
    'ThyssenKrupp': 1650,
    'Cobham': 1590,
    'DynCorpIntr': 1560,
    'KoreaAerospaceInd': 1550,
    'STEngineering': 1540,
    'BharatElectronics': 1460,
    'ManTechIntr': 1430,
    'UralVagonZavod': 1370,
    'JacobsEngineering': 1370,
    'Fluor': 1350,
    'LIGNex1': 1340,
    'TransDigm': 1330,
    'GKN': 1320,
    'MelroseInd': 1320,
    'UnitedLaunchAlliance': 1320,
    'UkrOboronProm': 1300,
    'Fujitsu': 1270,
    'SercoGroup': 1260,
    'PGZ': 1250,
    'TeledyneTechnologies': 1240,
    'Navantia': 1240,
    'Hensoldt': 1240,
    'Vectrus': 1230,
    'AerojetRocketdyne': 1220,
    'AustalUSA': 1160,
    'Austal': 1140,
    'SierraNevada': 1100,
    'IHI': 1090,
    'Nexter': 1080,
    'TurkishAerospaceInd': 1070,
    'BWXTechnologies': 1070,
    'Engility': 1070,
    'CAE': 1010,
    'MIT': 980,
    'Meggitt': 970,
    'CurtissWright': 970,
    'TheAerospace': 970,
    'DevonportRoyalDockyard': 940,
    'Ball': 930,
    'Moog': 920,
    'QinetiQ': 910,
    'RUAG': 900,
    'ViaSat': 860,
    'MitsubishiElectric': 860,
    'Arconic': 840,
    'NEC': 840,
    'Amphenol': 820,
}
