pastas = {
  'conchiglie': 'seashell shaped, usually furrowed (rigate)',
  'chifferi': 'short and wide macaroni',
  'farfalle':'bow tie or butterfly shaped',
  'fusilli': 'long, thick, corkscrew-shaped pasta that may be solid or hollow',
  'gnocchi': 'lobed shells. Not to be confused with gnocchi dumplings',
  'lasagna': 'square or rectangle sheets of pasta',
  'linguine': 'flattened spaghetti',
  'pennine': 'medium length tubes with ridges, cut diagonally at both ends',
  'ravioli': 'wwo squares of pasta on top of another, stuffed with fill',
  'spaghetti': 'long, thin, cylindrical pasta of Italian origin'
}
