# https://en.wikipedia.org/wiki/List_of_causes_of_death_by_rate
# data by deaths per 100,000

mortality_rates = {
  'Cardiovascular': 268.8,
  'InfectiousAndParasitic': 211.3,
  'CoronaryArtery': 115.8,
  'MalignantNeoplasms': 114.4,
  'Cerebrovascular': 88.5,
  'RespiratoryInfections': 63.7,
  'LowerRespiratoryTractInfections': 62.4,
  'Respiratory': 59.5,
  'UnintentionalInjuries': 57.0,
  'HIV': 44.6,
  'ChronicObstructivePulmonary': 44.1,
  'PerinatalConditions': 39.6,
  'Digestive': 31.6,
  'Diarrhea': 28.9,
  'IntentionalInjuries': 26.0,
  'Tuberculosis': 25.2,
  'Malaria': 20.4,
  'LungCancer': 20.0,
}
